package com.recordingblogs.oreffect;

/**
An envelope allows for changes in audio controls over time, as playback or mixing progresses.
For example, an amplitude envelope applied to a track in the session can allow the Orinj user
to specify that the amplitude of the track should begin to decrease gradually so that the track
can fade out.

Orinj uses several types of envelopes, allowing for changes in volume, pan, the dry mix of an
effect, and the wet mix of an effect.  Only dry mix and wet mix envelopes are handled in the
Orinj effect framework.

You can redistribute this file, modify it, adapt it, translate it, and/or distribute
the modified version, whether free of charge or not.  This file is distributed as is, without
warranty of any kind.

@author      Anton Kamenov
@version     4.0
*/

public interface EnvelopeInterface 
{
    /**
     * Get the value of the envelope at a specific point of playback time.  The value depends
     * on the type of envelope.  For volume, dry mix, or wet mix envelopes, this will be a gain
     * between 0 and 1.  For pan envelopes, this will be a value between -1 an 1, signifying far
     * left panning and far right panning respectively.
     * @param time The playback time
     * @return The envelope value
     */
    public double getValueAt(double time);
}
