package com.recordingblogs.oreffect;

import java.io.IOException;

/**
This interface is implemented by two classes in Orinj.  One of the classes is an
extension of java.io.ObjectInputStream.  This class is used by Orinj for the serialization
(reading) of sessions, loops, and other objects.  The second class is a custom Orinj class
used to read undo information that was saved before, when the users click on undo menu
commands.  Having these two classes extend the same interface allows Orinj to use the 
same functions for reading for serialization and for reading for undo (see the function
readObject in EffectInterface).  Note that the functions below largely match the 
member functions of java.io.ObjectInputStream.

You do not need to implement this interface.  However, when implementing EffectInterface, 
specifically the function readObject, the functions below are the only ones you can use
to read effect member data. 

You can redistribute this file, modify it, adapt it, translate it, and/or distribute 
the modified version, whether free of charge or not.  This file is distributed as is, without 
warranty of any kind.

@author      Anton Kamenov
@version     3.0
*/

public interface ReadInterface 
{
	/**
	 * Read a boolean
	 * @return The boolean that was read
	 * @throws IOException
	 * @since 3.0
	 */
	public boolean readBoolean() throws IOException;
	
	/**
	 * Read a byte
	 * @return The byte that was read
	 * @throws IOException
	 * @since 3.0
	 */
	public byte readByte() throws IOException;
	
	/**
	 * Read a short
	 * @return The short that was read
	 * @throws IOException
	 * @since 3.0
	 */
	public short readShort() throws IOException;
	
	/**
	 * Read an integer
	 * @return The integer that was read
	 * @throws IOException
	 * @since 3.0
	 */
	public int readInt() throws IOException;
	
	/**
	 * Read a long
	 * @return The long that was read
	 * @throws IOException
	 * @since 3.0
	 */
	public long readLong() throws IOException;
	
	/**
	 * Read a float
	 * @return The float that was read
	 * @throws IOException
	 * @since 3.0
	 */
	public float readFloat() throws IOException;
	
	/**
	 * Read a double
	 * @return The double that was read
	 * @throws IOException
	 * @since 3.0
	 */
	public double readDouble() throws IOException;
	
	/**
	 * Read a Java String
	 * @return The String that was read
	 * @throws IOException
	 * @throws ClassNotFoundException
	 * @since 3.0
	 */
	public String readString() throws IOException, ClassNotFoundException;
	
	/**
	 * Read an array of bytes.  The number of bytes to be read should be 
	 * the length of the array.  The actual number of bytes read will be returned
	 * (i.e., as in java.io.ObjectInputStream)
	 * @param value The array of bytes that will contain the bytes read
	 * 				This array should not be null
	 * @return The number of bytes read
	 * @throws IOException
	 * @since 3.0
	 */
	public int read(byte [] value) throws IOException;
}
